@@ -48,6 +48,11 @@ public:
 
   QString getKeysetName();
 
+  void openCurrentKeysetDialog();
+
+  void selectKeyset(
+    unsigned int targetID);
+
 protected:
   void keyPressEvent(
     QKeyEvent *event);
